@@ -432,7 +432,7 @@ instance HasParser Flags where
               [ help "Activate AI executor mode based on env vars",
                 reader exists,
                 -- Feel free to add env vars here.
-                env "CLAUDECODE",
+                unprefixedEnv "CLAUDECODE",
                 metavar "ANY"
               ]
           ]
